@@ -10,62 +10,27 @@
 import os
 import sys
 import curses
+import snr.constants.keybinds as Key
+import snr.constants.messages as Msg
 import snr.reader as Reader
 import snr.parser as Parser
 import snr.screen as Screen
 import snr.utilities as Utilities
 
 def main():
-
-
-    # :::: APP INFO :::::::::::::::: #
-
-    VERSION = 'v0.8.136-alpha'
-    APP = 'Simple Novel Reader'
-
-    # :::: KEYBINDINGS ::::::::::::: #
-
-    PAGE_UP = [ord('n'), ord('j'), ord(' ')]
-    PAGE_DOWN = [ord('p'), ord('k')]
-    NEXT_CHAPTER = [ord('N'), ord('l')]
-    PREVIOUS_CHAPTER = [ord('P'), ord('h')]
-    START_OF_CHAPTER = [ord('g'), ord('0')]
-    END_OF_CHAPTER = [ord('G'), ord('$')]
-    DARK_MODE = [ord('r')]
-    SPEED_MODE = [ord('s')]
-    HIGHLIGHT = [ord('v')]
-    DOUBLE_PAGE = [ord('d')]
-    JUSTIFY_FULL = [ord('f')]
-    V_PADDING_UP = [ord('>')]
-    H_PADDING_UP = [ord('.')]
-    V_PADDING_DOWN = [ord('<')]
-    H_PADDING_DOWN = [ord(',')]
-    PE_LINE_UP = [ord(']')]
-    PE_LINE_DOWN = [ord('[')]
-    TOC = [ord('t'), 9]
-    SELECT = [curses.KEY_ENTER, ord('o'), 13]
-    HELP = [ord('?'), curses.KEY_F1]
-    QUICKMARK = [ord('m')]
-    QUICKMARK_SLOT = [ord(str(x)) for x in range(1, 10)]
-    QUICKMARK_CLEAR = [ord('c')]
-    QUICKMARK_ALL = [ord('a')]
-    BOOKMARK = [ord('b')]
-    BOOKMARK_NEW = [ord('B')]
-    BOOKMARK_REMOVE = [ord('x')]
-    BOOKMARK_EDIT = [ord('e')]
-    BOOKMARK_DESCRIBE = [ord('l'), ord('d')]
-    ESCAPE = [curses.KEY_BACKSPACE, 8, 27]
-    REFRESH = [ord('R'), curses.KEY_F5]
-    QUIT = [ord('q')]
-
     # :::: BOOK INIT ::::::::::::::: #
 
     state = Reader.StateReader()
     try:
         fileinput = os.path.abspath(sys.argv[1])
     except IndexError:
-        fileinput = state.get_path()
-        default = True
+        try:
+            fileinput = state.get_path()
+            default = True
+        except KeyError:
+            print(Msg.HEADER)
+            print(Msg.ERR_NO_PATH)
+            exit()
     else:
         default = False
 
@@ -75,19 +40,26 @@ def main():
     path = reader.get_directory_path(toc_file)
     book = Parser.BookContent(path, toc_file, content_file)
     book_title = book.get_document_title()
+    number_of_chapters = book.get_number_of_chapters()
 
     # :::: READER CONFIG ::::::::::: #
 
     config = Reader.ConfigReader()
-    dark_mode = config.get_dark_mode()
-    speed_mode = config.get_speed_mode()
-    highlight = config.get_highlight()
-    double_page = config.get_double_page()
-    justify_full = config.get_justify_full()
-    h_padding = config.get_horizontal_padding()
-    v_padding = config.get_vertical_padding()
-    pe_line = config.get_pe_multiplier()
-    number_of_chapters = book.get_number_of_chapters()
+    try:
+        dark_mode = config.get_dark_mode()
+        speed_mode = config.get_speed_mode()
+        highlight = config.get_highlight()
+        double_page = config.get_double_page()
+        justify_full = config.get_justify_full()
+        hyphenation = config.get_hyphenation()
+        h_padding = config.get_horizontal_padding()
+        v_padding = config.get_vertical_padding()
+        pe_line = config.get_pe_multiplier()
+    except KeyError as err:
+        print(Msg.HEADER)
+        print(Msg.MISSING_KEY + str(err))
+        print(Msg.ERR_INVALID_CONFIG)
+        exit()
 
     # :::: CURSES CONFIG ::::::::::: #
 
@@ -98,8 +70,7 @@ def main():
         highlight,
         double_page,
         justify_full,
-        VERSION,
-        APP
+        hyphenation
     )
     screen = std_screen.get_screen()
     curses.noecho()
@@ -111,7 +82,7 @@ def main():
 
     escape = False
     screen_update = True
-    content_update = False
+    content_update = True
 
     if default:
         current_chapter = state.get_chapter()
@@ -129,8 +100,7 @@ def main():
         quickmarks = Utilities.Quickmarks()
         bookmarks = Utilities.Bookmarks()
 
-    content_pages = Screen.ContentPages(
-        screen,
+    content_pages = Screen.ContentPages(screen,
         book,
         current_chapter,
         dark_mode,
@@ -138,48 +108,11 @@ def main():
         highlight,
         double_page,
         justify_full,
+        hyphenation,
         v_padding,
         h_padding,
         pe_line
     )
-    toc_pages = Screen.TocPages(
-        screen,
-        book,
-        current_chapter,
-        dark_mode,
-        speed_mode,
-        highlight,
-        double_page,
-        justify_full,
-        v_padding,
-        h_padding
-    )
-    help_pages = Screen.HelpPages(
-        screen,
-        book,
-        current_chapter,
-        dark_mode,
-        speed_mode,
-        highlight,
-        double_page,
-        justify_full,
-        v_padding,
-        h_padding
-    )
-    bookmark_pages = Screen.BookmarkPages(
-        screen,
-        book,
-        current_chapter,
-        bookmarks,
-        dark_mode,
-        speed_mode,
-        highlight,
-        double_page,
-        justify_full,
-        v_padding,
-        h_padding
-    )
-
     current_page = content_pages.get_page_by_index(page_index)
     index = None
 
@@ -205,8 +138,7 @@ def main():
                 highlight,
                 double_page,
                 justify_full,
-                VERSION,
-                APP
+                hyphenation
             )
             screen = std_screen.get_screen()
             std_screen.redraw()
@@ -221,6 +153,7 @@ def main():
                 highlight,
                 double_page,
                 justify_full,
+                hyphenation,
                 v_padding,
                 h_padding,
                 pe_line
@@ -271,7 +204,7 @@ def main():
 
         x = screen.getch()
 
-        if x in PAGE_UP:
+        if x in Key.PAGE_UP:
                 if not double_page:
                     current_page += 1
                 else:
@@ -281,15 +214,27 @@ def main():
                     current_page = 0
                     content_update = True
 
-        if x in PAGE_DOWN:
+        if x in Key.PAGE_DOWN:
             if not double_page:
                 current_page -= 1
             else:
                 current_page -= 2
             if current_page < 0 and current_chapter != 0:
                 current_chapter -= 1
-                content_pages = Screen.ContentPages(screen, book, current_chapter, dark_mode, speed_mode, highlight, \
-                    double_page, justify_full, v_padding, h_padding, pe_line)
+                content_pages = Screen.ContentPages(
+                    screen,
+                    book,
+                    current_chapter,
+                    dark_mode,
+                    speed_mode,
+                    highlight,
+                    double_page,
+                    justify_full,
+                    hyphenation,
+                    v_padding,
+                    h_padding,
+                    pe_line
+                )
                 if not double_page or content_pages.get_number_of_pages() < 2:
                     current_page = content_pages.get_number_of_pages() - 1
                 else:
@@ -297,50 +242,55 @@ def main():
             elif current_page < 0 and current_chapter == 0:
                 current_page = 0
 
-        if x in NEXT_CHAPTER:
+        if x in Key.NEXT_CHAPTER:
             if current_chapter != number_of_chapters:
                 current_chapter += 1
                 current_page = 0
                 content_update = True
 
-        if x in PREVIOUS_CHAPTER:
+        if x in Key.PREVIOUS_CHAPTER:
             if current_chapter != 0:
                 current_chapter -= 1
                 current_page = 0
                 content_update = True
 
-        if x in START_OF_CHAPTER:
+        if x in Key.START_OF_CHAPTER:
             current_page = 0
 
-        if x in END_OF_CHAPTER:
+        if x in Key.END_OF_CHAPTER:
             current_page = content_pages.get_number_of_pages() - 1
 
-        if x in DARK_MODE:
+        if x in Key.DARK_MODE:
             dark_mode = not dark_mode
             screen_update = True
             content_update = True
 
-        if x in SPEED_MODE:
+        if x in Key.SPEED_MODE:
             speed_mode = not speed_mode
             screen_update = True
             content_update = True
 
-        if x in HIGHLIGHT:
+        if x in Key.HIGHLIGHT:
             highlight = not highlight
             screen_update = True
             content_update = True
 
-        if x in DOUBLE_PAGE:
+        if x in Key.DOUBLE_PAGE:
             double_page = not double_page
             screen_update = True
             content_update = True
 
-        if x in JUSTIFY_FULL:
+        if x in Key.JUSTIFY_FULL:
             justify_full = not justify_full
             screen_update = True
             content_update = True
 
-        if x in V_PADDING_UP:
+        if x in Key.HYPHENATION:
+            hyphenation = not hyphenation
+            screen_update = True
+            content_update = True
+
+        if x in Key.V_PADDING_UP:
             v_padding = content_pages.increase_v_padding(v_padding)
             index = content_pages.get_current_page_index(current_page)
             content_pages = Screen.ContentPages(
@@ -352,6 +302,7 @@ def main():
                 highlight,
                 double_page,
                 justify_full,
+                hyphenation,
                 v_padding,
                 h_padding,
                 pe_line
@@ -359,7 +310,7 @@ def main():
             current_page = content_pages.get_page_by_index(index)
             screen_update = True
 
-        if x in H_PADDING_UP:
+        if x in Key.H_PADDING_UP:
             h_padding = content_pages.increase_h_padding(h_padding)
             index = content_pages.get_current_page_index(current_page)
             content_pages= Screen.ContentPages(
@@ -371,6 +322,7 @@ def main():
                 highlight,
                 double_page,
                 justify_full,
+                hyphenation,
                 v_padding,
                 h_padding,
                 pe_line
@@ -378,7 +330,7 @@ def main():
             current_page = content_pages.get_page_by_index(index)
             screen_update = True
 
-        if x in V_PADDING_DOWN:
+        if x in Key.V_PADDING_DOWN:
             v_padding = content_pages.decrease_v_padding(v_padding)
             index = content_pages.get_current_page_index(current_page)
             content_pages = Screen.ContentPages(screen,
@@ -389,6 +341,7 @@ def main():
                 highlight,
                 double_page,
                 justify_full,
+                hyphenation,
                 v_padding,
                 h_padding,
                 pe_line
@@ -396,7 +349,7 @@ def main():
             current_page = content_pages.get_page_by_index(index)
             screen_update = True
 
-        if x in H_PADDING_DOWN:
+        if x in Key.H_PADDING_DOWN:
             h_padding = content_pages.decrease_h_padding(h_padding)
             index = content_pages.get_current_page_index(current_page)
             content_pages = Screen.ContentPages(
@@ -408,6 +361,7 @@ def main():
                 highlight,
                 double_page,
                 justify_full,
+                hyphenation,
                 v_padding,
                 h_padding,
                 pe_line
@@ -415,13 +369,13 @@ def main():
             current_page = content_pages.get_page_by_index(index)
             screen_update = True
 
-        if x in PE_LINE_UP:
+        if x in Key.PE_LINE_UP:
             pe_line = content_pages.increase_pe_multiplier()
 
-        if x in PE_LINE_DOWN:
+        if x in Key.PE_LINE_DOWN:
             pe_line = content_pages.decrease_pe_multiplier()
 
-        if x in QUICKMARK_SLOT:
+        if x in Key.QUICKMARK_SLOT:
             if quickmarks.is_set(chr(x)):
                 current_chapter = quickmarks.get_chapter(chr(x))
                 content_pages = Screen.ContentPages(
@@ -433,44 +387,45 @@ def main():
                     highlight,
                     double_page,
                     justify_full,
+                    hyphenation,
                     v_padding,
                     h_padding,
                     pe_line
                 )
                 current_page = content_pages.get_page_by_index(quickmarks.get_index(chr(x)))
 
-        if x in QUICKMARK_CLEAR:
+        if x in Key.QUICKMARK_CLEAR:
             y = screen.getch()
 
-            if y in QUICKMARK_SLOT:
+            if y in Key.QUICKMARK_SLOT:
                 quickmarks.set_quickmark(
                     chr(y),
                     None,
                     None
                 )
 
-            if y in QUICKMARK_ALL:
+            if y in Key.QUICKMARK_ALL:
                 quickmarks = Utilities.Quickmarks()
 
-        if x in QUICKMARK:
+        if x in Key.QUICKMARK:
             content_pages.print_page(current_page, bookmarks, quickmarks, True)
 
             y = screen.getch()
 
-            if y in QUICKMARK_SLOT:
+            if y in Key.QUICKMARK_SLOT:
                 quickmarks.set_quickmark(
                     chr(y),
                     current_chapter,
                     content_pages.get_current_page_index(current_page)
                 )
 
-        if x in BOOKMARK_NEW:
+        if x in Key.BOOKMARK_NEW:
             index = content_pages.get_current_page_index(current_page)
             bookmarks.create(current_chapter, index)
             screen_update = True
             content_update = True
 
-        if x in BOOKMARK:
+        if x in Key.BOOKMARK:
             escape_bookmark = False
             current_bookmark_page = 0
             current_bookmark_pos = 0
@@ -479,7 +434,7 @@ def main():
 
                 y = screen.getch()
 
-                if y in PAGE_UP:
+                if y in Key.PAGE_UP:
                     if bookmarks.has_bookmarks():
                         current_bookmark_pos += 1
                         if current_bookmark_pos == \
@@ -490,7 +445,7 @@ def main():
                             else:
                                 current_bookmark_page = 0
 
-                if y in PAGE_DOWN:
+                if y in Key.PAGE_DOWN:
                     if bookmarks.has_bookmarks():
                         current_bookmark_pos -= 1
                         if current_bookmark_pos == -1:
@@ -501,7 +456,7 @@ def main():
                             current_bookmark_pos = \
                                 bookmark_pages.get_number_of_positions(current_bookmark_page) - 1
 
-                if y in SELECT:
+                if y in Key.SELECT:
                     if bookmarks.has_bookmarks():
                         bookmark_key = \
                             bookmark_pages.get_position_id(current_bookmark_page, current_bookmark_pos)
@@ -515,6 +470,7 @@ def main():
                             highlight,
                             double_page,
                             justify_full,
+                            hyphenation,
                             v_padding,
                             h_padding,
                             pe_line
@@ -523,7 +479,7 @@ def main():
                     escape_bookmark = True
                     content_update = True
 
-                if y in BOOKMARK_REMOVE:
+                if y in Key.BOOKMARK_REMOVE:
                     if bookmarks.has_bookmarks():
                         bookmark_key = \
                             bookmark_pages.get_position_id(current_bookmark_page, current_bookmark_pos)
@@ -547,7 +503,7 @@ def main():
                             if current_bookmark_pos > bookmark_pages.get_number_of_positions(current_bookmark_page) - 1:
                                 current_bookmark_pos = bookmark_pages.get_number_of_positions(current_bookmark_page) - 1
 
-                if y in BOOKMARK_EDIT:
+                if y in Key.BOOKMARK_EDIT:
                     if bookmarks.has_bookmarks():
                         bookmark_key = \
                             bookmark_pages.get_position_id(current_bookmark_page, current_bookmark_pos)
@@ -573,8 +529,7 @@ def main():
                             highlight,
                             double_page,
                             justify_full,
-                            VERSION,
-                            APP
+                            hyphenation
                         )
                         screen = std_screen.get_screen()
                         std_screen.redraw()
@@ -588,6 +543,7 @@ def main():
                             highlight,
                             double_page,
                             justify_full,
+                            hyphenation,
                             v_padding,
                             h_padding,
                             pe_line
@@ -596,7 +552,7 @@ def main():
                         current_description_page = 0
                         content_pages.print_page(current_page, bookmarks, quickmarks)
 
-                if y in BOOKMARK_DESCRIBE:
+                if y in Key.BOOKMARK_DESCRIBE:
                     if bookmarks.has_bookmarks():
                         escape_description = False
                         current_description_page = 0
@@ -622,26 +578,26 @@ def main():
 
                             z = screen.getch()
 
-                            if z in PAGE_UP:
+                            if z in Key.PAGE_UP:
                                 current_description_page += 1
                                 if current_description_page == bookmark_description_pages.get_number_of_pages():
                                     current_description_page = 0
 
-                            if z in PAGE_DOWN:
+                            if z in Key.PAGE_DOWN:
                                 current_description_page -= 1
                                 if current_description_page < 0:
                                     current_description_page = bookmark_description_pages.get_number_of_pages() - 1
 
-                            if z in BOOKMARK_DESCRIBE or z in ESCAPE:
+                            if z in Key.BOOKMARK_DESCRIBE or z in Key.ESCAPE:
                                 content_update = True
                                 escape_description = True
 
-                            if z in REFRESH:
+                            if z in Key.REFRESH:
                                 screen_update = True
                                 content_update = True
                                 escape_description = True
 
-                            if z in QUIT:
+                            if z in Key.QUIT:
                                 escape = True
                                 escape_description = True
                                 curses.endwin()
@@ -663,8 +619,7 @@ def main():
                                     highlight,
                                     double_page,
                                     justify_full,
-                                    VERSION,
-                                    APP
+                                    hyphenation
                                 )
                                 screen = std_screen.get_screen()
                                 std_screen.redraw()
@@ -678,6 +633,7 @@ def main():
                                     highlight,
                                     double_page,
                                     justify_full,
+                                    hyphenation,
                                     v_padding,
                                     h_padding,
                                     pe_line
@@ -713,16 +669,16 @@ def main():
                                 current_page = content_pages.get_page_by_index(index)
                                 current_description_page = 0
 
-                if y in BOOKMARK or y in ESCAPE:
+                if y in Key.BOOKMARK or y in Key.ESCAPE:
                     content_update = True
                     escape_bookmark = True
 
-                if y in REFRESH:
+                if y in Key.REFRESH:
                     screen_update = True
                     content_update = True
                     escape_bookmark = True
 
-                if y in QUIT:
+                if y in Key.QUIT:
                     escape = True
                     escape_bookmark = True
                     state.save(
@@ -744,8 +700,7 @@ def main():
                         highlight,
                         double_page,
                         justify_full,
-                        VERSION,
-                        APP
+                        hyphenation
                     )
                     screen = std_screen.get_screen()
                     std_screen.redraw()
@@ -759,6 +714,7 @@ def main():
                         highlight,
                         double_page,
                         justify_full,
+                        hyphenation,
                         v_padding,
                         h_padding,
                         pe_line
@@ -780,7 +736,7 @@ def main():
                     current_page = content_pages.get_page_by_index(index)
                     current_bookmark_page = 0
 
-        if x in TOC:
+        if x in Key.TOC:
             escape_toc = False
             current_toc_page = 0
             current_toc_pos = 0
@@ -789,7 +745,7 @@ def main():
 
                 y = screen.getch()
 
-                if y in PAGE_UP:
+                if y in Key.PAGE_UP:
                     current_toc_pos += 1
                     if current_toc_pos == \
                         toc_pages.get_number_of_positions(current_toc_page):
@@ -799,7 +755,7 @@ def main():
                         else:
                             current_toc_page = 0
 
-                if y in PAGE_DOWN:
+                if y in Key.PAGE_DOWN:
                     current_toc_pos -= 1
                     if current_toc_pos == -1:
                         if current_toc_page > 0:
@@ -809,23 +765,23 @@ def main():
                         current_toc_pos = \
                             toc_pages.get_number_of_positions(current_toc_page) - 1
 
-                if y in SELECT:
+                if y in Key.SELECT:
                     current_page = 0
                     current_chapter = \
                         toc_pages.get_position_id(current_toc_page, current_toc_pos) - 1
                     escape_toc = True
                     content_update = True
 
-                if y in TOC or y in ESCAPE:
+                if y in Key.TOC or y in Key.ESCAPE:
                     content_update = True
                     escape_toc = True
 
-                if y in REFRESH:
+                if y in Key.REFRESH:
                     screen_update = True
                     content_update = True
                     escape_toc = True
 
-                if y in QUIT:
+                if y in Key.QUIT:
                     escape = True
                     escape_toc = True
                     state.save(
@@ -847,8 +803,7 @@ def main():
                         highlight,
                         double_page,
                         justify_full,
-                        VERSION,
-                        APP
+                        hyphenation
                     )
                     screen = std_screen.get_screen()
                     std_screen.redraw()
@@ -862,6 +817,7 @@ def main():
                         highlight,
                         double_page,
                         justify_full,
+                        hyphenation,
                         v_padding,
                         h_padding,
                         pe_line
@@ -882,7 +838,7 @@ def main():
                     current_page = content_pages.get_page_by_index(index)
                     current_toc_page = 0
 
-        if x in HELP:
+        if x in Key.HELP:
             escape_help = False
             current_help_page = 0
             while escape_help == False:
@@ -890,26 +846,26 @@ def main():
 
                 y = screen.getch()
 
-                if y in PAGE_UP:
+                if y in Key.PAGE_UP:
                     current_help_page += 1
                     if current_help_page == help_pages.get_number_of_pages():
                         current_help_page = 0
 
-                if y in PAGE_DOWN:
+                if y in Key.PAGE_DOWN:
                     current_help_page -= 1
                     if current_help_page < 0:
                         current_help_page = help_pages.get_number_of_pages() - 1
 
-                if y in HELP or y in ESCAPE:
+                if y in Key.HELP or y in Key.ESCAPE:
                     content_update = True
                     escape_help = True
 
-                if y in REFRESH:
+                if y in Key.REFRESH:
                     screen_update = True
                     content_update = True
                     escape_help = True
 
-                if y in QUIT:
+                if y in Key.QUIT:
                     escape = True
                     escape_help = True
                     curses.endwin()
@@ -931,8 +887,7 @@ def main():
                         highlight,
                         double_page,
                         justify_full,
-                        VERSION,
-                        APP
+                        hyphenation
                     )
                     screen = std_screen.get_screen()
                     std_screen.redraw()
@@ -946,6 +901,7 @@ def main():
                         highlight,
                         double_page,
                         justify_full,
+                        hyphenation,
                         v_padding,
                         h_padding,
                         pe_line
@@ -966,7 +922,7 @@ def main():
                     current_page = content_pages.get_page_by_index(index)
                     current_help_page = 0
 
-        if x in REFRESH:
+        if x in Key.REFRESH:
             curses.endwin()
             std_screen = Screen.Screen(
                 book_title,
@@ -975,14 +931,13 @@ def main():
                 highlight,
                 double_page,
                 justify_full,
-                VERSION,
-                APP
+                hyphenation
             )
             screen = std_screen.get_screen()
             screen_update = True
             content_update = True
 
-        if x in QUIT:
+        if x in Key.QUIT:
             escape = True
             curses.endwin()
             state.save(
@@ -1003,8 +958,7 @@ def main():
                 highlight,
                 double_page,
                 justify_full,
-                VERSION,
-                APP
+                hyphenation
             )
             screen = std_screen.get_screen()
             index = content_pages.get_current_page_index(current_page)
